# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CloudIntegrationAwsExternalIdArgs', 'CloudIntegrationAwsExternalId']

@pulumi.input_type
class CloudIntegrationAwsExternalIdArgs:
    def __init__(__self__):
        """
        The set of arguments for constructing a CloudIntegrationAwsExternalId resource.
        """
        pass


@pulumi.type_token("wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId")
class CloudIntegrationAwsExternalId(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 __props__=None):
        """
        Provides an External ID for use in Amazon Web Services IAM Roles. This allows External IDs to be created and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        external_id = wavefront.CloudIntegrationAwsExternalId("external_id")
        ```

        ## Import

        External IDs can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId external_id uGJdkH3k
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CloudIntegrationAwsExternalIdArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an External ID for use in Amazon Web Services IAM Roles. This allows External IDs to be created and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        external_id = wavefront.CloudIntegrationAwsExternalId("external_id")
        ```

        ## Import

        External IDs can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId external_id uGJdkH3k
        ```

        :param str resource_name: The name of the resource.
        :param CloudIntegrationAwsExternalIdArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudIntegrationAwsExternalIdArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudIntegrationAwsExternalIdArgs.__new__(CloudIntegrationAwsExternalIdArgs)

        super(CloudIntegrationAwsExternalId, __self__).__init__(
            'wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'CloudIntegrationAwsExternalId':
        """
        Get an existing CloudIntegrationAwsExternalId resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = CloudIntegrationAwsExternalIdArgs.__new__(CloudIntegrationAwsExternalIdArgs)

        return CloudIntegrationAwsExternalId(resource_name, opts=opts, __props__=__props__)

